==> xoops-2.4.5.tbz: www/xoops/htdocs/language/english/uploader.php <==
<?php
/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code 
 which is considered copyrighted (c) material of the original comment or credit authors.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 *  Xoops Language
 *
 * @copyright       The XOOPS Project http://sourceforge.net/projects/xoops/
 * @license         http://www.fsf.org/copyleft/gpl.html GNU public license
 * @package         kernel
 * @subpackage      Xoops Uploader Language
 * @since           2.0.0
 * @author          Kazumi Ono <onokazu@xoops.org>
 * @version         $Id: uploader.php 3152 2009-04-18 13:30:57Z catzwolf $
 */
defined('XOOPS_ROOT_PATH') or die('Restricted access');

// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
define('_ER_UP_MIMETYPELOAD', 'Error loading mimetypes definition');
define('_ER_UP_FILENOTFOUND', 'File not found');
define('_ER_UP_INVALIDFILESIZE', 'Invalid File Size');
define('_ER_UP_FILENAMEEMPTY', 'Filename Is Empty');
define('_ER_UP_NOFILEUPLOADED', 'No file uploaded');
define('_ER_UP_ERROROCCURRED', 'Error occurred: Error #%s');
define('_ER_UP_UPLOADDIRNOTSET', 'Upload directory not set');
define('_ER_UP_FAILEDOPENDIR', 'Failed opening directory: %s');
define('_ER_UP_FAILEDOPENDIRWRITE', 'Failed opening directory with write permission: %s');
define('_ER_UP_FILESIZETOOLARGE', 'File size too large (Maximum %u bytes): %u bytes');
define('_ER_UP_FILEWIDTHTOOLARGE', 'File width too large (Maximum %u px): %u px');
define('_ER_UP_FILEHEIGHTTOOLARGE', 'File height too large (Maximum %u px): %u px');
define('_ER_UP_MIMETYPENOTALLOWED', 'MIME type not allowed: %s');
define('_ER_UP_FAILEDUPLOADFILE', 'Failed uploading file: %s');
define('_ER_UP_FAILEDFETCHIMAGESIZE', 'Failed fetching image size of %s, skipping max dimension check..');
define('_ER_UP_UNKNOWNFILETYPEREJECTED', 'Unknown filetype rejected');
define('_ER_UP_ERRORSRETURNED', 'Errors Returned While Uploading file : %s');
define('_ER_UP_INVALIDIMAGEFILE', 'Invalid image file');
define('_ER_UP_SUSPICIOUSREFUSED', 'Suspicious image upload refused');
define('_ER_UP_INVALIDFILENAME', 'Invalid file name');
define('_ER_UP_FAILEDSAVEFILE', 'Failed to save file to %s');

?>

==> xoops-2.5.5.tbz: www/xoops/htdocs/language/english/uploader.php <==
<?php
// $Id: uploader.php 8066 2011-11-06 05:09:33Z beckmi $
// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
define('_ER_UP_MIMETYPELOAD', 'Error loading mimetypes definition');
define('_ER_UP_FILENOTFOUND', 'File not found');
define('_ER_UP_INVALIDFILESIZE', 'Invalid File Size');
define('_ER_UP_FILENAMEEMPTY', 'Filename Is Missing');
define('_ER_UP_NOFILEUPLOADED', 'No file uploaded');
define('_ER_UP_ERROROCCURRED', 'Unexpected Error #%s');
define('_ER_UP_UPLOADDIRNOTSET', 'Upload directory not set');
define('_ER_UP_FAILEDOPENDIR', 'Failed opening directory: %s');
define('_ER_UP_FAILEDOPENDIRWRITE', 'Failed opening directory with write permission: %s');
define('_ER_UP_FILESIZETOOLARGE', 'File size too large (Maximum %u bytes): %u bytes');
define('_ER_UP_FILEWIDTHTOOLARGE', 'File width too large (Maximum %u px): %u px');
define('_ER_UP_FILEHEIGHTTOOLARGE', 'File height too large (Maximum %u px): %u px');
define('_ER_UP_MIMETYPENOTALLOWED', 'File of MIME type: %s is not allowed');
define('_ER_UP_FAILEDUPLOADFILE', 'Failed uploading file: %s');
define('_ER_UP_FAILEDFETCHIMAGESIZE', 'Failed fetching image size of %s, skipping max dimension check..');
define('_ER_UP_UNKNOWNFILETYPEREJECTED', "The file you're trying to upload is not supported by this site/server.");
define('_ER_UP_ERRORSRETURNED', 'Errors Returned While Uploading file: %s');
define('_ER_UP_INVALIDIMAGEFILE', 'Invalid image file');
define('_ER_UP_SUSPICIOUSREFUSED', 'Suspicious image upload refused');
define('_ER_UP_INVALIDFILENAME', 'Invalid file name');
define('_ER_UP_FAILEDSAVEFILE', 'Failed to save file to %s');

?>
